@@ -235,7 +235,7 @@ def double_sided_gaussian(p, x, y):
 
 ### Correct Bragg peak positions, making a circular coordinate system
 
-def correct_braggpeak_elliptical_distortions(braggpeaks,p_ellipse,centered=True,name=None):
+def correct_braggpeak_elliptical_distortions(braggpeaks,p_ellipse,centered=True):
     """
     Given some elliptical distortions with ellipse parameters p and some measured
     PointListArray of Bragg peak positions braggpeaks, returns the elliptically corrected
@@ -269,8 +269,7 @@ def correct_braggpeak_elliptical_distortions(braggpeaks,p_ellipse,centered=True,
         )
 
     # Correct distortions
-    name = braggpeaks.name+"_ellipsecorrected" if name is None else name
-    braggpeaks_corrected = braggpeaks.copy(name=name)
+    braggpeaks_corrected = braggpeaks.copy(name=braggpeaks.name + "_ellipsecorrected")
     for Rx in range(braggpeaks_corrected.shape[0]):
         for Ry in range(braggpeaks_corrected.shape[1]):
             pointlist = braggpeaks_corrected.get_pointlist(Rx, Ry)
