@@ -751,7 +751,7 @@ def _get_latest_model(model_path = None):
         except:
             pass
         # download the json file with the meta data
-        download_file_from_google_drive('1uofpSGy7PDlpRiSnuvS5XemnpVbzpcle','./tmp/model_metadata.json')
+        download_file_from_google_drive('1zlneUM88zBniFnymiIejHxEzAoYrK9ct','./tmp/model_metadata.json')
         with open('./tmp/model_metadata.json') as f:
             metadata = json.load(f)
             file_id = metadata['file_id']
@@ -787,4 +787,4 @@ def _get_latest_model(model_path = None):
         model = tf.keras.models.load_model(model_path,
                                            custom_objects={'lrScheduler': crystal4D.utils.utils.lrScheduler(128)})
     
-    return model
\ No newline at end of file
+    return model
