@@ -9,11 +9,6 @@ Functions for finding Braggdisks (AI/ML) using cupy and tensorflow-gpu
 import numpy as np
 from time import time
 
-try:
-    from numba import cuda
-except ImportError:
-    raise ImportError("Import Error: Please install numba before proceeding")
-
 try:
     import cupy as cp
 except:
